<?php
/***********************************************************************

  Copyright (C) 2002-2007  Rickard Andersson (rickard@punbb.org)

  This file is part of PunBB.

  PunBB is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  PunBB is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************/


define('PUN_ROOT', '../');
require PUN_ROOT.'include/common.php';
require PUN_ROOT.'include/common_admin.php';

$section = isset($_GET['section']) ? $_GET['section'] : null;

if ($pun_user['g_id'] != PUN_ADMIN)
	message($lang_common['No permission']);

// Load the admin.php language file
require PUN_ROOT.'lang/'.$pun_user['language'].'/admin.php';


if (isset($_POST['form_sent']))
{
	$form = array_map('trim', $_POST['form']);

	// Validate input depending on section
	switch ($section)
	{
		case 'essentials':
		{
			if ($form['board_title'] == '')
				message($lang_admin['Error no board title']);

			// Clean default_lang, default_style, and sef
			$form['default_lang'] = preg_replace('#[\.\\\/]#', '', $form['default_lang']);
			$form['default_style'] = preg_replace('#[\.\\\/]#', '', $form['default_style']);
			$form['sef'] = preg_replace('#[\.\\\/]#', '', $form['sef']);

			// Make sure default_lang and default_style exist
			if (!file_exists(PUN_ROOT.'style/'.$form['default_style'].'/'.$form['default_style'].'.css'))
				message($lang_common['Bad request']);
			if (!file_exists(PUN_ROOT.'lang/'.$form['default_lang'].'/common.php'))
				message($lang_common['Bad request']);

			$form['timeout_visit'] = intval($form['timeout_visit']);
			$form['timeout_online'] = intval($form['timeout_online']);
			$form['redirect_delay'] = intval($form['redirect_delay']);

			if ($form['timeout_online'] >= $form['timeout_visit'])
				message($lang_admin['Error timeout value']);

			if (!isset($form['sef'])) $form['sef'] = 'Default';

			if ($form['maintenance_message'] != '')
				$form['maintenance_message'] = pun_linebreaks($form['maintenance_message']);
			else
				$form['maintenance_message'] = $lang_admin['Maintenance message default'];

			if (!isset($form['maintenance']) || $form['maintenance'] != '1') $form['maintenance'] = '0';

			break;
		}
		case 'features':
		{
			if ($form['additional_navlinks'] != '')
				$form['additional_navlinks'] = trim(pun_linebreaks($form['additional_navlinks']));

			if (!isset($form['search_all_forums']) || $form['search_all_forums'] != '1') $form['search_all_forums'] = '0';
			if (!isset($form['subscriptions']) || $form['subscriptions'] != '1') $form['subscriptions'] = '0';
			if (!isset($form['force_guest_email']) || $form['force_guest_email'] != '1') $form['force_guest_email'] = '0';
			if (!isset($form['mod_edit_users']) || $form['mod_edit_users'] != '1') $form['mod_edit_users'] = '0';
			if (!isset($form['mod_rename_users']) || $form['mod_rename_users'] != '1') $form['mod_rename_users'] = '0';
			if (!isset($form['mod_change_passwords']) || $form['mod_change_passwords'] != '1') $form['mod_change_passwords'] = '0';
			if (!isset($form['mod_ban_users']) || $form['mod_ban_users'] != '1') $form['mod_ban_users'] = '0';
			if (!isset($form['show_version']) || $form['show_version'] != '1') $form['show_version'] = '0';
			if (!isset($form['users_online']) || $form['users_online'] != '1') $form['users_online'] = '0';
			if (!isset($form['show_user_info']) || $form['show_user_info'] != '1') $form['show_user_info'] = '0';
			if (!isset($form['show_post_count']) || $form['show_post_count'] != '1') $form['show_post_count'] = '0';
			if (!isset($form['show_dot']) || $form['show_dot'] != '1') $form['show_dot'] = '0';
			if (!isset($form['topic_views']) || $form['topic_views'] != '1') $form['topic_views'] = '0';
			if (!isset($form['quick_post']) || $form['quick_post'] != '1') $form['quick_post'] = '0';
			if (!isset($form['censoring']) || $form['censoring'] != '1') $form['censoring'] = '0';
			if (!isset($form['ranks']) || $form['ranks'] != '1') $form['ranks'] = '0';
			if (!isset($form['quickjump']) || $form['quickjump'] != '1') $form['quickjump'] = '0';
			if (!isset($form['gzip']) || $form['gzip'] != '1') $form['gzip'] = '0';

			break;
		}
		case 'registration':
		{
			if ($form['rules_message'] != '')
				$form['rules_message'] = pun_linebreaks($form['rules_message']);
			else
				$form['rules_message'] = $lang_admin['Rules default'];

			if (!isset($form['allow_banned_email']) || $form['allow_banned_email'] != '1') $form['allow_banned_email'] = '0';
			if (!isset($form['allow_dupe_email']) || $form['allow_dupe_email'] != '1') $form['allow_dupe_email'] = '0';
			if (!isset($form['regs_allow']) || $form['regs_allow'] != '1') $form['regs_allow'] = '0';
			if (!isset($form['regs_verify']) || $form['regs_verify'] != '1') $form['regs_verify'] = '0';
			if (!isset($form['rules']) || $form['rules'] != '1') $form['rules'] = '0';

			break;
		}
		case 'content':
		{
			// Clean avatars_dir
			$form['avatars_dir'] = str_replace("\0", '', $form['avatars_dir']);

			// Make sure avatars_dir doesn't end with a slash
			if (substr($form['avatars_dir'], -1) == '/')
				$form['avatars_dir'] = substr($form['avatars_dir'], 0, -1);

			$form['indent_num_spaces'] = intval($form['indent_num_spaces']);
			$form['avatars_width'] = intval($form['avatars_width']);
			$form['avatars_height'] = intval($form['avatars_height']);
			$form['avatars_size'] = intval($form['avatars_size']);

			$form['disp_topics_default'] = (intval($form['disp_topics_default']) > 0) ? intval($form['disp_topics_default']) : 1;
			$form['disp_posts_default'] = (intval($form['disp_posts_default']) > 0) ? intval($form['disp_posts_default']) : 1;

			if (!isset($form['message_bbcode']) || $form['message_bbcode'] != '1') $form['message_bbcode'] = '0';
			if (!isset($form['message_img_tag']) || $form['message_img_tag'] != '1') $form['message_img_tag'] = '0';
			if (!isset($form['message_all_caps']) || $form['message_all_caps'] != '1') $form['message_all_caps'] = '0';
			if (!isset($form['subject_all_caps']) || $form['subject_all_caps'] != '1') $form['subject_all_caps'] = '0';
			if (!isset($form['signatures']) || $form['signatures'] != '1') $form['signatures'] = '0';
			if (!isset($form['sig_bbcode']) || $form['sig_bbcode'] != '1') $form['sig_bbcode'] = '0';
			if (!isset($form['sig_img_tag']) || $form['sig_img_tag'] != '1') $form['sig_img_tag'] = '0';
			if (!isset($form['sig_all_caps']) || $form['sig_all_caps'] != '1') $form['sig_all_caps'] = '0';
			if (!isset($form['mod_edit_users']) || $form['mod_edit_users'] != '1') $form['mod_edit_users'] = '0';
			if (!isset($form['mod_rename_users']) || $form['mod_rename_users'] != '1') $form['mod_rename_users'] = '0';
			if (!isset($form['mod_change_passwords']) || $form['mod_change_passwords'] != '1') $form['mod_change_passwords'] = '0';
			if (!isset($form['mod_ban_users']) || $form['mod_ban_users'] != '1') $form['mod_ban_users'] = '0';
			if (!isset($form['avatars']) || $form['avatars'] != '1') $form['avatars'] = '0';

			break;
		}
		case 'communications':
		{
			require PUN_ROOT.'include/email.php';

			$form['admin_email'] = strtolower($form['admin_email']);

			if (!is_valid_email($form['admin_email']))
				message($lang_admin['Error invalid admin e-mail']);

			$form['webmaster_email'] = strtolower($form['webmaster_email']);

			if (!is_valid_email($form['webmaster_email']))
				message($lang_admin['Error invalid web e-mail']);

			if ($form['mailing_list'] != '')
				$form['mailing_list'] = strtolower(preg_replace('/[\s]/', '', $form['mailing_list']));

			if ($form['announcement_message'] != '')
				$form['announcement_message'] = pun_linebreaks($form['announcement_message']);
			else
				$form['announcement_message'] = $lang_admin['Announcement message default'];

			if (!isset($form['regs_report']) || $form['regs_report'] != '1') $form['regs_report'] = '0';
			if (!isset($form['announcement']) || $form['announcement'] != '1') $form['announcement'] = '0';
			if (!isset($form['smtp_ssl']) || $form['smtp_ssl'] != '1') $form['smtp_ssl'] = '0';

			break;
		}
	}

	($hook = get_hook('aop_update_options')) ? eval($hook) : null;

	while (list($key, $input) = @each($form))
	{
		// Only update permission values that have changed
		if (array_key_exists('p_'.$key, $pun_config) && $pun_config['p_'.$key] != $input)
			$db->query('UPDATE '.$db->prefix.'config SET conf_value='.$input.' WHERE conf_name=\'p_'.$db->escape($key).'\'') or error('Unable to update board config', __FILE__, __LINE__, $db->error());

		// Only update option values that have changed
		if (array_key_exists('o_'.$key, $pun_config) && $pun_config['o_'.$key] != $input)
		{
			if ($input != '' || is_int($input))
				$value = '\''.$db->escape($input).'\'';
			else
				$value = 'NULL';

			$db->query('UPDATE '.$db->prefix.'config SET conf_value='.$value.' WHERE conf_name=\'o_'.$db->escape($key).'\'') or error('Unable to update board config', __FILE__, __LINE__, $db->error());
		}
	}

	// Regenerate the config cache
	require_once PUN_ROOT.'include/cache.php';
	generate_config_cache();

	redirect(pun_link($pun_url['admin_options_'.$section]), $lang_admin['Options updated'].' '.$lang_admin['Redirect']);
}


if (!$section || $section == 'essentials')
{
	// Setup breadcrumbs
	$pun_page['crumbs'] = array(
		array($pun_config['o_board_title'], pun_link($pun_url['index'])),
		array($lang_admin['Forum administration'], pun_link($pun_url['admin_index'])),
		$lang_admin['Essentials']
	);

	define('PUN_PAGE_SECTION', 'options');
	define('PUN_PAGE', 'admin-options-essentials');
	require PUN_ROOT.'header.php';

	$fld_count = 0;

?>
<div id="pun-main1" class="a-section a-main a-admin">

	<h1 class="main-title"><span><?php echo end($pun_page['crumbs']) ?></span></h1>

<?php echo generate_admin_menu(); ?>

	<div class="b-section b-dataform">
		<div class="c-section c-form">
			<form method="post" accept-charset="utf-8" action="<?php echo pun_link($pun_url['admin_options_essentials']) ?>">
			<div class="panel">
				<input type="hidden" name="csrf_token" value="<?php echo $pun_user['csrf_token'] ?>" />
				<input type="hidden" name="form_sent" value="1" />
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Essentials setup'] ?>: </span></h2>
					<p><?php echo $lang_admin['Setup intro'] ?></p>
				</div>
				<fieldset class="textset">
					<legend><span><?php echo $lang_admin['Personalize legend'] ?></span></legend>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Board title'] ?></label><br />
						<span class="input"><input type="text" id="<?php echo 'fld'.$fld_count ?>" name="form[board_title]" size="50" maxlength="255" value="<?php echo htmlspecialchars($pun_config['o_board_title']) ?>" /><br /> <em class="field-info"><?php echo $lang_admin['Board title info'] ?></em></span>
					</p>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Board description'] ?></label><br />
						<span class="input"><input type="text" id="<?php echo 'fld'.$fld_count ?>" name="form[board_desc]" size="50" maxlength="255" value="<?php echo htmlspecialchars($pun_config['o_board_desc']) ?>" /><br /> <em class="field-info"><?php echo $lang_admin['Board description info'] ?></em></span>
					</p>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Default style'] ?></label><br />
						<span class="input"><select id="<?php echo 'fld'.$fld_count ?>" name="form[default_style]">
<?php

		$styles = array();
		$d = dir(PUN_ROOT.'style');
		while (($entry = $d->read()) !== false)
		{
			if ($entry != '.' && $entry != '..' && is_dir(PUN_ROOT.'style/'.$entry) && file_exists(PUN_ROOT.'style/'.$entry.'/'.$entry.'.css'))
				$styles[] = $entry;
		}
		$d->close();

		@natcasesort($styles);

		while (list(, $temp) = @each($styles))
		{
			if ($pun_config['o_default_style'] == $temp)
				echo "\t\t\t\t\t\t\t\t".'<option value="'.$temp.'" selected="selected">'.str_replace('_', ' ', $temp).'</option>'."\n";
			else
				echo "\t\t\t\t\t\t\t\t".'<option value="'.$temp.'">'.str_replace('_', ' ', $temp).'</option>'."\n";
		}

?>
						</select></span>
					</p>

				</fieldset>
				<fieldset class="textset">
					<legend><span><?php echo $lang_admin['Addressing legend'] ?></span></legend>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['URL scheme'] ?></label><br />
						<span class="input"><select id="<?php echo 'fld'.$fld_count ?>" name="form[sef]">
<?php

		$url_schemes = array();
		$d = dir(PUN_ROOT.'include/url');
		while (($entry = $d->read()) !== false)
		{
			if ($entry != '.' && $entry != '..' && substr($entry, strlen($entry)-4) == '.php')
				$url_schemes[] = $entry;
		}
		$d->close();

		@natcasesort($url_schemes);

		while (list(, $temp) = @each($url_schemes))
		{
			$temp = substr($temp,0,-4);
			if ($pun_config['o_sef'] == $temp)
				echo "\t\t\t\t\t\t\t\t".'<option value="'.$temp.'" selected="selected">'.str_replace('_', ' ', $temp).'</option>'."\n";
			else
				echo "\t\t\t\t\t\t\t\t".'<option value="'.$temp.'">'.str_replace('_', ' ', $temp).'</option>'."\n";
		}

?>
						</select></span>
					</p>
					<div class="form-warn"><p><?php echo '<strong>'.$lang_admin['Important'].'</strong> '.$lang_admin['URL scheme info'] ?></p></div>
				</fieldset>
				<fieldset class="textset">
					<legend><span><?php echo $lang_admin['Board defaults legend'] ?></span></legend>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Default language'] ?></label><br />
						<span class="input">
							<select id="<?php echo 'fld'.$fld_count ?>" name="form[default_lang]">
<?php

		$languages = array();
		$d = dir(PUN_ROOT.'lang');
		while (($entry = $d->read()) !== false)
		{
			if ($entry != '.' && $entry != '..' && is_dir(PUN_ROOT.'lang/'.$entry) && file_exists(PUN_ROOT.'lang/'.$entry.'/common.php'))
				$languages[] = $entry;
		}
		$d->close();

		@natcasesort($languages);

		while (list(, $temp) = @each($languages))
		{
			if ($pun_config['o_default_lang'] == $temp)
				echo "\t\t\t\t\t\t\t\t\t".'<option value="'.$temp.'" selected="selected">'.$temp.'</option>'."\n";
			else
				echo "\t\t\t\t\t\t\t\t\t".'<option value="'.$temp.'">'.$temp.'</option>'."\n";
		}

?>
							</select>
							<br /> <em><?php echo $lang_admin['Default language info'] ?></em>
						</span>
					</p>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Default timezone'] ?></label><br />
						<span class="input"><select id="<?php echo 'fld'.$fld_count ?>" name="form[default_timezone]">
							<option value="-12"<?php if ($pun_config['o_default_timezone'] == -12 ) echo ' selected="selected"' ?>>-12</option>
							<option value="-11"<?php if ($pun_config['o_default_timezone'] == -11) echo ' selected="selected"' ?>>-11</option>
							<option value="-10"<?php if ($pun_config['o_default_timezone'] == -10) echo ' selected="selected"' ?>>-10</option>
							<option value="-9.5"<?php if ($pun_config['o_default_timezone'] == -9.5) echo ' selected="selected"' ?>>-09.5</option>
							<option value="-9"<?php if ($pun_config['o_default_timezone'] == -9 ) echo ' selected="selected"' ?>>-09</option>
							<option value="-8.5"<?php if ($pun_config['o_default_timezone'] == -8.5) echo ' selected="selected"' ?>>-08.5</option>
							<option value="-8"<?php if ($pun_config['o_default_timezone'] == -8 ) echo ' selected="selected"' ?>>-08 PST</option>
							<option value="-7"<?php if ($pun_config['o_default_timezone'] == -7 ) echo ' selected="selected"' ?>>-07 MST</option>
							<option value="-6"<?php if ($pun_config['o_default_timezone'] == -6 ) echo ' selected="selected"' ?>>-06 CST</option>
							<option value="-5"<?php if ($pun_config['o_default_timezone'] == -5 ) echo ' selected="selected"' ?>>-05 EST</option>
							<option value="-4"<?php if ($pun_config['o_default_timezone'] == -4 ) echo ' selected="selected"' ?>>-04 AST</option>
							<option value="-3.5"<?php if ($pun_config['o_default_timezone'] == -3.5) echo ' selected="selected"' ?>>-03.5</option>
							<option value="-3"<?php if ($pun_config['o_default_timezone'] == -3 ) echo ' selected="selected"' ?>>-03 ADT</option>
							<option value="-2"<?php if ($pun_config['o_default_timezone'] == -2 ) echo ' selected="selected"' ?>>-02</option>
							<option value="-1"<?php if ($pun_config['o_default_timezone'] == -1) echo ' selected="selected"' ?>>-01</option>
							<option value="0"<?php if ($pun_config['o_default_timezone'] == 0) echo ' selected="selected"' ?>>00 GMT</option>
							<option value="1"<?php if ($pun_config['o_default_timezone'] == 1) echo ' selected="selected"' ?>>+01 CET</option>
							<option value="2"<?php if ($pun_config['o_default_timezone'] == 2 ) echo ' selected="selected"' ?>>+02</option>
							<option value="3"<?php if ($pun_config['o_default_timezone'] == 3 ) echo ' selected="selected"' ?>>+03</option>
							<option value="3.5"<?php if ($pun_config['o_default_timezone'] == 3.5) echo ' selected="selected"' ?>>+03.5</option>
							<option value="4"<?php if ($pun_config['o_default_timezone'] == 4 ) echo ' selected="selected"' ?>>+04</option>
							<option value="4.5"<?php if ($pun_config['o_default_timezone'] == 4.5) echo ' selected="selected"' ?>>+04.5</option>
							<option value="5"<?php if ($pun_config['o_default_timezone'] == 5 ) echo ' selected="selected"' ?>>+05</option>
							<option value="5.5"<?php if ($pun_config['o_default_timezone'] == 5.5) echo ' selected="selected"' ?>>+05.5</option>
							<option value="6"<?php if ($pun_config['o_default_timezone'] == 6 ) echo ' selected="selected"' ?>>+06</option>
							<option value="6.5"<?php if ($pun_config['o_default_timezone'] == 6.5) echo ' selected="selected"' ?>>+06.5</option>
							<option value="7"<?php if ($pun_config['o_default_timezone'] == 7 ) echo ' selected="selected"' ?>>+07</option>
							<option value="8"<?php if ($pun_config['o_default_timezone'] == 8 ) echo ' selected="selected"' ?>>+08</option>
							<option value="9"<?php if ($pun_config['o_default_timezone'] == 9 ) echo ' selected="selected"' ?>>+09</option>
							<option value="9.5"<?php if ($pun_config['o_default_timezone'] == 9.5) echo ' selected="selected"' ?>>+09.5</option>
							<option value="10"<?php if ($pun_config['o_default_timezone'] == 10) echo ' selected="selected"' ?>>+10</option>
							<option value="10.5"<?php if ($pun_config['o_default_timezone'] == 10.5) echo ' selected="selected"' ?>>+10.5</option>
							<option value="11"<?php if ($pun_config['o_default_timezone'] == 11) echo ' selected="selected"' ?>>+11</option>
							<option value="11.5"<?php if ($pun_config['o_default_timezone'] == 11.5) echo ' selected="selected"' ?>>+11.5</option>
							<option value="12"<?php if ($pun_config['o_default_timezone'] == 12 ) echo ' selected="selected"' ?>>+12</option>
							<option value="13"<?php if ($pun_config['o_default_timezone'] == 13 ) echo ' selected="selected"' ?>>+13</option>
						</select></span>
					</p>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Time format'] ?></label><br />
						<span class="input"><input type="text" id="<?php echo 'fld'.$fld_count ?>" name="form[time_format]" size="25" maxlength="25" value="<?php echo htmlspecialchars($pun_config['o_time_format']) ?>" /><br /> <em>[<?php echo $lang_admin['Current format'].' '.gmdate($pun_config['o_time_format']) ?>]</em></span>
					</p>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Date format'] ?></label><br />
						<span class="input"><input type="text" id="<?php echo 'fld'.$fld_count ?>" name="form[date_format]" size="25" maxlength="25" value="<?php echo htmlspecialchars($pun_config['o_date_format']) ?>" /><br /> <em>[<?php echo $lang_admin['Current format'].' '.gmdate($pun_config['o_date_format']) ?>]</em></span>
					</p>
				</fieldset>
				<fieldset class="textset">
					<legend><span><?php echo $lang_admin['Timeouts legend'] ?></span></legend>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Visit timeout'] ?></label><br />
						<span class="input"><input type="text" id="<?php echo 'fld'.$fld_count ?>" name="form[timeout_visit]" size="5" maxlength="5" value="<?php echo $pun_config['o_timeout_visit'] ?>" /><br /> <em><?php echo $lang_admin['Visit timeout info'] ?></em></span>
					</p>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Online timeout'] ?></label><br />
						<span class="input"><input type="text" id="<?php echo 'fld'.$fld_count ?>" name="form[timeout_online]" size="5" maxlength="5" value="<?php echo $pun_config['o_timeout_online'] ?>" /><br /> <em><?php echo $lang_admin['Online timeout info'] ?></em></span>
					</p>
					<p class="field">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Redirect time'] ?></label><br />
						<span class="input"><input type="text" id="<?php echo 'fld'.$fld_count ?>" name="form[redirect_delay]" size="5" maxlength="3" value="<?php echo $pun_config['o_redirect_delay'] ?>" /><br /> <em><?php echo $lang_admin['Redirect time info'] ?></em></span>
					</p>
				</fieldset>
			</div>
			<div class="panel">
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Essentials maintenance'] ?>: </span></h2>
					<p><?php echo $lang_admin['Maintenance mode intro'] ?></p>
				</div>
				<fieldset class="checkset">
					<legend><span><?php echo $lang_admin['Maintenance mode legend'] ?></span></legend>
					<p id="maintenance" class="field">
						<span class="input"><input type="checkbox" id="<?php echo 'fld'.(++$fld_count) ?>" name="form[maintenance]" value="1"<?php if ($pun_config['o_maintenance'] == '1') echo ' checked="checked"' ?> />&#160;<label for="<?php echo 'fld'.$fld_count ?>"><?php echo $lang_admin['Maintenance mode label'] ?></label></span>
					</p>
					<p class="field areafield">
						<label for="<?php echo 'fld'.(++$fld_count) ?>"><?php echo $lang_admin['Maintenance message'] ?></label><br />
						<span class="input"><textarea id="<?php echo 'fld'.$fld_count ?>" name="form[maintenance_message]" rows="5" cols="55"><?php echo htmlspecialchars($pun_config['o_maintenance_message']) ?></textarea></span>
					</p>
				</fieldset>
				<div class="form-warn">
					<p><strong><?php echo $lang_admin['Warning'] ?></strong> <?php echo $lang_admin['Maintenance mode info'] ?></p>
				</div>
				<p class="formsubmit"><input type="submit" class="button" name="save" value="<?php echo $lang_admin['Save changes'] ?>" /></p>
			</div>
			</form>
		</div>
	</div>

</div>
<?php

}
else if ($section == 'features')
{
	// Setup breadcrumbs
	$pun_page['crumbs'] = array(
		array($pun_config['o_board_title'], pun_link($pun_url['index'])),
		array($lang_admin['Forum administration'], pun_link($pun_url['admin_index'])),
		$lang_admin['Features']
	);

	define('PUN_PAGE_SECTION', 'options');
	define('PUN_PAGE', 'admin-options-features');
	require PUN_ROOT.'header.php';

?>
<div id="pun-main1" class="a-section a-main a-admin">

	<h1 class="main-title"><span><?php echo end($pun_page['crumbs']) ?></span></h1>

<?php echo generate_admin_menu(); ?>

	<div class="b-section b-dataform">
		<div class="c-section c-form">
			<form method="post" accept-charset="utf-8" action="<?php echo pun_link($pun_url['admin_options_features']) ?>">
			<div class="panel">
				<input type="hidden" name="csrf_token" value="<?php echo $pun_user['csrf_token'] ?>" />
				<input type="hidden" name="form_sent" value="1" />
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Features'] ?>: </span></h2>
					<p><?php echo $lang_admin['Features intro'] ?></p>
				</div>
				<fieldset class="checkset" id="fs1">
					<legend><span><?php echo $lang_admin['Users legend'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs1f1" name="form[subscriptions]" value="1"<?php if ($pun_config['o_subscriptions'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f1"><?php echo $lang_admin['Subscriptions'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs1f2" name="form[search_all_forums]" value="1"<?php if ($pun_config['o_search_all_forums'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f2"><?php echo $lang_admin['Search all forums'] ?></label><br /> <em class="field-info"><?php echo $lang_admin['Search all forums info'] ?></em></span><br />
						<span class="input"><input type="checkbox" id="fs1f3" name="form[force_guest_email]" value="1"<?php if ($pun_config['p_force_guest_email'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f3"><?php echo $lang_admin['Require guest email'] ?></label></span><br />
					</p>
				</fieldset>
				<fieldset class="checkset" id="fs2">
					<legend><span><?php echo $lang_admin['Mods legend'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs2f1" name="form[mod_edit_users]" value="1"<?php if ($pun_config['p_mod_edit_users'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs2f1"><?php echo $lang_admin['Mod edit profiles'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs2f2" name="form[mod_rename_users]" value="1"<?php if ($pun_config['p_mod_rename_users'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs2f2"><?php echo $lang_admin['Mod edit username'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs2f3" name="form[mod_change_passwords]" value="1"<?php if ($pun_config['p_mod_change_passwords'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs2f3"><?php echo $lang_admin['Mod change pass'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs2f4" name="form[mod_ban_users]" value="1"<?php if ($pun_config['p_mod_ban_users'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs2f4"><?php echo $lang_admin['Mod bans'] ?></label></span><br />
					</p>
				</fieldset>
				<fieldset class="checkset" id="fs3">
					<legend><span><?php echo $lang_admin['Information legend'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs3f1" name="form[show_version]" value="1"<?php if ($pun_config['o_show_version'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f1"><?php echo $lang_admin['Version number'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs3f2" name="form[users_online]" value="1"<?php if ($pun_config['o_users_online'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f2"><?php echo $lang_admin['Users online'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs3f3" name="form[show_user_info]" value="1"<?php if ($pun_config['o_show_user_info'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f3"><?php echo $lang_admin['User info in posts'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs3f4" name="form[show_post_count]" value="1"<?php if ($pun_config['o_show_post_count'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f4"><?php echo $lang_admin['User post count'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs3f5" name="form[show_dot]" value="1"<?php if ($pun_config['o_show_dot'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f5"><?php echo $lang_admin['User has posted'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs3f6" name="form[topic_views]" value="1"<?php if ($pun_config['o_topic_views'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f6"><?php echo $lang_admin['Count topic views'] ?></label></span><br />
					</p>
				</fieldset>
				<fieldset class="checkset" id="fs4">
					<legend><span><?php echo $lang_admin['Board legend'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs4f1" name="form[quickpost]" value="1"<?php if ($pun_config['o_quickpost'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs4f1"><?php echo $lang_admin['Quick post'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs4f2" name="form[censoring]" value="1"<?php if ($pun_config['o_censoring'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs4f2"><?php echo $lang_admin['Censor words'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs4f3" name="form[ranks]" value="1"<?php if ($pun_config['o_ranks'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs4f3"><?php echo $lang_admin['User ranks'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs4f4" name="form[quickjump]" value="1"<?php if ($pun_config['o_quickjump'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs4f4"><?php echo $lang_admin['Quick jump'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs4f5" name="form[gzip]" value="1"<?php if ($pun_config['o_gzip'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs4f5"><?php echo $lang_admin['GZip output'] ?></label><br /> <em class="field-info"><?php echo $lang_admin['GZip output info'] ?></em></span><br />
					</p>
				</fieldset>
				<fieldset class="textset" id="fs5">
					<legend><span><?php echo $lang_admin['Board menu legend'] ?></span></legend>
					<p class="field areafield">
						<label for="fs5f1"><?php echo $lang_admin['Additional menu items'] ?></label><br />
						<span class="input"><textarea id="fs5f1" name="form[additional_navlinks]" rows="3" cols="55"><?php echo htmlspecialchars($pun_config['o_additional_navlinks']) ?></textarea><br /> <em class="field-info"><?php echo $lang_admin['Additional menu items info'] ?></em></span>
					</p>
				</fieldset>
<?php ($hook = get_hook('aop_section_features')) ? eval($hook) : null; ?>
				<p class="formsubmit"><input type="submit" class="button" name="save" value="<?php echo $lang_admin['Save changes'] ?>" /></p>
			</div>
			</form>
		</div>
	</div>

</div>
<?php

}
else if ($section == 'content')
{
	// Setup breadcrumbs
	$pun_page['crumbs'] = array(
		array($pun_config['o_board_title'], pun_link($pun_url['index'])),
		array($lang_admin['Forum administration'], pun_link($pun_url['admin_index'])),
		$lang_admin['Content']
	);

	define('PUN_PAGE_SECTION', 'options');
	define('PUN_PAGE', 'admin-options-content');
	require PUN_ROOT.'header.php';

?>
<div id="pun-main1" class="a-section a-main a-admin">

	<h1 class="main-title"><span><?php echo end($pun_page['crumbs']) ?></span></h1>

<?php echo generate_admin_menu(); ?>

	<div class="b-section b-dataform">
		<div class="c-section c-form">
			<form method="post" accept-charset="utf-8" action="<?php echo pun_link($pun_url['admin_options_content']) ?>">
			<div class="panel">
				<input type="hidden" name="csrf_token" value="<?php echo $pun_user['csrf_token'] ?>" />
				<input type="hidden" name="form_sent" value="1" />
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Posts and sigs'] ?>: </span></h2>
					<p><?php echo $lang_admin['Posts and sigs intro'] ?></p>
				</div>
				<fieldset class="checkset" id="fs1">
					<legend><span><?php echo $lang_admin['Posts'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs1f1" name="form[message_bbcode]" value="1"<?php if ($pun_config['p_message_bbcode'] == '1') echo ' checked="checked"' ?> /> <label for="fs1f1"><?php echo $lang_admin['Allow BBCode'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs1f2" name="form[message_img_tag]" value="1"<?php if ($pun_config['p_message_img_tag'] == '1') echo ' checked="checked"' ?> /> <label for="fs1f2"><?php echo $lang_admin['Allow img'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs1f3" name="form[smilies]" value="1"<?php if ($pun_config['o_smilies'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f3"><?php echo $lang_admin['Smilies in posts'] ?></label></span>
						<span class="input"><input type="checkbox" id="fs1f4" name="form[make_links]" value="1"<?php if ($pun_config['o_make_links'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f4"><?php echo $lang_admin['Make clickable links'] ?></label></span>
						<span class="input"><input type="checkbox" id="fs1f5" name="form[message_all_caps]" value="1"<?php if ($pun_config['p_message_all_caps'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f5"><?php echo $lang_admin['All caps message'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs1f6" name="form[subject_all_caps]" value="1"<?php if ($pun_config['p_subject_all_caps'] == '1') echo ' checked="checked"' ?> /> <label for="fs1f6"><?php echo $lang_admin['All caps subject'] ?></label></span><br />
					</p>
				</fieldset>
				<fieldset class="textset" id="fs2">
					<legend><span>Posting</span></legend>
					<p class="field">
						<label for="fs2f1"><?php echo $lang_admin['Indent size'] ?></label><br />
						<span class="input"><input type="text" id="fs2f1" name="form[indent_num_spaces]" size="3" maxlength="3" value="<?php echo $pun_config['o_indent_num_spaces'] ?>" /><br /> <em class="field-info"><?php echo $lang_admin['Indent size info'] ?></em></span>
					</p>
				</fieldset>
				<fieldset class="checkset" id="fs3">
					<legend><span>Signatures</span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs3f1" name="form[signatures]" value="1"<?php if ($pun_config['o_signatures'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f1"><?php echo $lang_admin['Signatures'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs3f2" name="form[sig_bbcode]" value="1"<?php if ($pun_config['p_sig_bbcode'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f2"><?php echo $lang_admin['BBCode in sigs'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs3f3" name="form[sig_img_tag]" value="1"<?php if ($pun_config['p_sig_img_tag'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f3"><?php echo $lang_admin['Img in sigs'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs3f4" name="form[smilies_sig]" value="1"<?php if ($pun_config['o_smilies_sig'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f4"><?php echo $lang_admin['Smilies in signatures'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs3f5" name="form[sig_all_caps]" value="1"<?php if ($pun_config['p_sig_all_caps'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs3f5"><?php echo $lang_admin['All caps sigs'] ?></label></span><br />
					</p>
				</fieldset>
				<fieldset class="textset" id="fs4">
					<legend><span>Signatures</span></legend>
					<p class="field">
						<label for="fs4f1"><?php echo $lang_admin['Max sig length'] ?></label><br />
						<span class="input"><input type="text" id="fs4f1" name="form[sig_length]" size="5" maxlength="5" value="<?php echo $pun_config['p_sig_length'] ?>" /> <em><?php echo $lang_admin['Max sig length info'] ?></em></span>
					</p>
					<p class="field">
						<label for="fs4f2"><?php echo $lang_admin['Max sig lines'] ?></label><br />
						<span class="input"><input type="text" id="fs4f2" name="form[sig_lines]" size="3" maxlength="3" value="<?php echo $pun_config['p_sig_lines'] ?>" /> <em><?php echo $lang_admin['Max sig lines info'] ?></em></span>
					</p>
				</fieldset>
			</div>
			<div class="panel">
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Avatars'] ?>: </span></h2>
					<p><?php echo $lang_admin['Avatars intro'] ?></p>
				</div>
				<fieldset class="checkset" id="fs5">
					<legend><span><?php echo $lang_admin['Use avatars'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs5f1" name="form[avatars]" value="1"<?php if ($pun_config['o_avatars'] == '1') echo ' checked="checked"' ?> /> <label for="fs5f1"><?php echo $lang_admin['Use avatars info'] ?></label></span>
					</p>
					<p class="field">
						<label for="fs5f2"><?php echo $lang_admin['Upload directory'] ?></label><br />
						<span class="input"><input type="text" id="fs5f2" name="form[avatars_dir]" size="35" maxlength="50" value="<?php echo htmlspecialchars($pun_config['o_avatars_dir']) ?>" /><br /> <em class="field-info"><?php echo $lang_admin['Upload directory info'] ?></em></span>
					</p>
					<p class="field">
						<label for="fs5f3"><?php echo $lang_admin['Max width'] ?></label><br />
						<span class="input"><input type="text" id="fs5f3" name="form[avatars_width]" size="6" maxlength="5" value="<?php echo $pun_config['o_avatars_width'] ?>" /> <em><?php echo $lang_admin['Max width info'] ?></em></span>
					</p>
					<p class="field">
						<label for="fs5f4"><?php echo $lang_admin['Max height'] ?></label><br />
						<span class="input"><input type="text" id="fs5f4" name="form[avatars_height]" size="6" maxlength="5" value="<?php echo $pun_config['o_avatars_height'] ?>" /> <em><?php echo $lang_admin['Max height info'] ?></em></span>
					</p>
					<p class="field">
						<label for="fs5f5"><?php echo $lang_admin['Max size'] ?></label><br />
						<span class="input"><input type="text" id="fs5f5" name="form[avatars_size]" size="6" maxlength="6" value="<?php echo $pun_config['o_avatars_size'] ?>" /> <em><?php echo $lang_admin['Max size info'] ?></em></span>
					</p>
				</fieldset>
			</div>
			<div class="panel">
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Pagination'] ?>: </span></h2>
					<p><?php echo $lang_admin['Pagination intro'] ?></p>
				</div>
				<fieldset class="textset" id="fs6">
					<p class="field">
						<label for="fs6f1"><?php echo $lang_admin['Topics per page'] ?></label><br />
						<span class="input"><input type="text" id="fs6f1" name="form[disp_topics_default]" size="3" maxlength="3" value="<?php echo $pun_config['o_disp_topics_default'] ?>" /></span>
					</p>
					<p class="field">
						<label for="fs6f2"><?php echo $lang_admin['Posts per page'] ?></label><br />
						<span class="input"><input type="text" id="fs6f2" name="form[disp_posts_default]" size="3" maxlength="3" value="<?php echo $pun_config['o_disp_posts_default'] ?>" /></span>
					</p>
					<p class="field">
						<label for="fs6f3"><?php echo $lang_admin['Topic review'] ?></label><br />
						<span class="input"><input type="text" id="fs6f3" name="form[topic_review]" size="3" maxlength="3" value="<?php echo $pun_config['o_topic_review'] ?>" /><br /> <em><?php echo $lang_admin['Topic review info'] ?></em></span>
					</p>
				</fieldset>
				<p class="formsubmit"><input type="submit" class="button" name="save" value="<?php echo $lang_admin['Save changes'] ?>" /></p>
			</div>
			</form>
		</div>
	</div>

</div>
<?php

}
else if ($section == 'registration')
{
	// Setup breadcrumbs
	$pun_page['crumbs'] = array(
		array($pun_config['o_board_title'], pun_link($pun_url['index'])),
		array($lang_admin['Forum administration'], pun_link($pun_url['admin_index'])),
		$lang_admin['Registration']
	);

	define('PUN_PAGE_SECTION', 'options');
	define('PUN_PAGE', 'admin-options-registration');
	require PUN_ROOT.'header.php';

?>
<div id="pun-main1" class="a-section a-main a-admin">

	<h1 class="main-title"><span><?php echo end($pun_page['crumbs']) ?></span></h1>

<?php echo generate_admin_menu(); ?>

	<div class="b-section b-dataform">
		<div class="c-section c-form">
			<form method="post" accept-charset="utf-8" action="<?php echo pun_link($pun_url['admin_options_registration']) ?>">
			<div class="panel">
				<input type="hidden" name="csrf_token" value="<?php echo $pun_user['csrf_token'] ?>" />
				<input type="hidden" name="form_sent" value="1" />
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Registration head'] ?>: </span></h2>
					<p><?php echo $lang_admin['Registration intro'] ?></p>
				</div>
				<fieldset class="checkset" id="fs1">
					<legend><span><?php echo $lang_admin['Registration legend'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs1f1" name="form[regs_allow]" value="1"<?php if ($pun_config['o_regs_allow'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f1"><?php echo $lang_admin['New registrations'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs1f2" name="form[regs_verify]" value="1"<?php if ($pun_config['o_regs_verify'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f2" ><?php echo $lang_admin['Verify registrations'] ?></label><br /> <em class="field-info"><?php echo $lang_admin['Verify registrations info'] ?></em></span><br />
						<span class="input"><input type="checkbox" id="fs1f3" name="form[allow_banned_email]" value="1"<?php if ($pun_config['p_allow_banned_email'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f3"><?php echo $lang_admin['Allow banned email'] ?></label></span><br />
						<span class="input"><input type="checkbox" id="fs1f4" name="form[allow_dupe_email]" value="1"<?php if ($pun_config['p_allow_dupe_email'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f4"><?php echo $lang_admin['Allow dupe email'] ?></label></span><br />
					</p>
				</fieldset>
			</div>
			<div class="panel">
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Rules head'] ?>: </span></h2>
					<p><?php echo $lang_admin['Rules intro'] ?></p>
				</div>
				<fieldset class="checkset" id="fs2">
					<legend><span><?php echo $lang_admin['Rules legend'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs2f1" name="form[rules]" value="1"<?php if ($pun_config['o_rules'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs2f1"><?php echo $lang_admin['Require rules'] ?></label></span>
					</p>
					<p class="field areafield">
						<label for="fs2f2"><?php echo $lang_admin['Compose rules'] ?></label><br />
						<span class="input"><textarea id="fs2f2" name="form[rules_message]" rows="10" cols="55"><?php echo htmlspecialchars($pun_config['o_rules_message']) ?></textarea> <em class="field-info"><?php echo $lang_admin['Rules info'] ?></em></span>
					</p>
				</fieldset>
				<p class="formsubmit"><input type="submit" class="button" name="save" value="<?php echo $lang_admin['Save changes'] ?>" /></p>
			</div>
			</form>
		</div>
	</div>

</div>
<?php

}
else if ($section == 'communications')
{
	// Setup breadcrumbs
	$pun_page['crumbs'] = array(
		array($pun_config['o_board_title'], pun_link($pun_url['index'])),
		array($lang_admin['Forum administration'], pun_link($pun_url['admin_index'])),
		$lang_admin['Communications']
	);

	define('PUN_PAGE_SECTION', 'options');
	define('PUN_PAGE', 'admin-options-communications');
	require PUN_ROOT.'header.php';

?>
<div id="pun-main1" class="a-section a-main a-admin">

	<h1 class="main-title"><span><?php echo end($pun_page['crumbs']) ?></span></h1>

<?php echo generate_admin_menu(); ?>

	<div class="b-section b-dataform">
		<div class="c-section c-form">
			<form method="post" accept-charset="utf-8" action="<?php echo pun_link($pun_url['admin_options_communications']) ?>">
			<div class="panel">
				<input type="hidden" name="csrf_token" value="<?php echo $pun_user['csrf_token'] ?>" />
				<input type="hidden" name="form_sent" value="1" />
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['E-mail'] ?>: </span></h2>
					<p><?php echo $lang_admin['E-mail settings intro'] ?></p>
				</div>
				<fieldset class="textset" id="fs1">
					<legend><span><?php echo $lang_admin['E-mail legend'] ?></span></legend>
					<p class="field">
						<label for="fs1f1"><?php echo $lang_admin['Admin e-mail'] ?></label><br />
						<span class="input"><input type="text" id="fs1f1" name="form[admin_email]" size="50" maxlength="80" value="<?php echo $pun_config['o_admin_email'] ?>" /></span>
					</p>
					<p class="field">
						<label for="fs1f2"><?php echo $lang_admin['Webmaster e-mail'] ?></label><br />
						<span class="input"><input type="text" id="fs1f2" name="form[webmaster_email]" size="50" maxlength="80" value="<?php echo $pun_config['o_webmaster_email'] ?>" /></span>
					</p>
					<p class="field">
						<label for="fs1f3"><?php echo $lang_admin['SMTP server address'] ?></label><br />
						<span class="input"><input type="text" id="fs1f3" name="form[smtp_host]" size="30" maxlength="100" value="<?php echo htmlspecialchars($pun_config['o_smtp_host']) ?>" /><br /> <em class="field-info"><?php echo $lang_admin['SMTP server address info'] ?></em></span>
					</p>
					<p class="field">
						<label for="fs1f4"><?php echo $lang_admin['SMTP username'] ?></label><br />
						<span class="input"><input type="text" id="fs1f4" name="form[smtp_user]" size="25" maxlength="50" value="<?php echo htmlspecialchars($pun_config['o_smtp_user']) ?>" /><br /> <em class="field-info"><?php echo $lang_admin['SMTP username info'] ?></em></span>
					</p>
					<p class="field">
						<label for="fs1f5"><?php echo $lang_admin['SMTP password'] ?></label><br />
						<span class="input"><input type="text" id="fs1f5" name="form[smtp_pass]" size="25" maxlength="50" value="<?php echo htmlspecialchars($pun_config['o_smtp_pass']) ?>" /><br /> <em class="field-info"><?php echo $lang_admin['SMTP password info'] ?></em></span>
					</p>
					<p class="field">
						<label for="fs1f6"><?php echo $lang_admin['SMTP SSL'] ?></label><br />
						<span class="input"><input type="checkbox" id="fs1f6" name="form[smtp_ssl]" value="1"<?php if ($pun_config['o_smtp_ssl'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs1f6"><?php echo $lang_admin['SMTP SSL info'] ?></label></span>
					</p>
				</fieldset>

			</div>
			<div class="panel">
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Announcement'] ?>: </span></h2>
					<p><?php echo $lang_admin['Announcement intro'] ?></p>
				</div>
				<fieldset class="checkset" id="fs2">
					<legend><span><?php echo $lang_admin['Announcement legend'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs2f1" name="form[announcement]" value="1"<?php if ($pun_config['o_announcement'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs2f1"><?php echo $lang_admin['Display announcement info'] ?></label></span>
					</p>
					<p class="field areafield">
						<label for="fs2f2"><?php echo $lang_admin['Announcement message'] ?></label><br />
						<span class="input"><textarea id="fs2f2" name="form[announcement_message]" rows="10" cols="55"><?php echo htmlspecialchars($pun_config['o_announcement_message']) ?></textarea></span>
					</p>
				</fieldset>
			</div>
			<div class="panel">
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Reports head'] ?>: </span></h2>
					<p><?php echo $lang_admin['Reports intro'] ?></p>
				</div>
				<fieldset class="radioset" id="fs3">
					<legend><span><?php echo $lang_admin['Report method'] ?></span></legend>
					<p class="field">
					<span class="input"><input type="radio" id="fs3f1" name="form[report_method]" value="0"<?php if ($pun_config['o_report_method'] == '0') echo ' checked="checked"' ?> /> <label for="fs3f1"><?php echo $lang_admin['Report internal'] ?></label></span><br />
					<span class="input"><input type="radio" id="fs3f2" name="form[report_method]" value="1"<?php if ($pun_config['o_report_method'] == '1') echo ' checked="checked"' ?> /> <label for="fs3f2"><?php echo $lang_admin['Report email'] ?></label></span><br />
					<span class="input"><input type="radio" id="fs3f3" name="form[report_method]" value="2"<?php if ($pun_config['o_report_method'] == '2') echo ' checked="checked"' ?> /> <label for="fs3f3"><?php echo $lang_admin['Report both'] ?></label></span><br />
					</p>
				</fieldset>
				<fieldset class="checkset" id="fs4">
					<legend><span><?php echo $lang_admin['Report new registrations'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs4f1" name="form[regs_report]" value="1"<?php if ($pun_config['o_regs_report'] == '1') echo ' checked="checked"' ?> />&#160;<label for="fs4f1"><?php echo $lang_admin['Report new registrations info'] ?></label></span>
					</p>
				</fieldset>
				<fieldset class="textset" id="fs5">
					<legend><span><?php echo $lang_admin['Mailing list legend'] ?></span></legend>
					<p class="field areafield">
						<label for="fs5f1"><?php echo $lang_admin['Mailing list'] ?></label><br />
						<span class="input"><textarea id="fs5f1" name="form[mailing_list]" rows="5" cols="55"><?php echo htmlspecialchars($pun_config['o_mailing_list']) ?></textarea><br /> <em class="field-info"><?php echo $lang_admin['Mailing list info'] ?></em></span>
					</p>
				</fieldset>
				<p class="formsubmit"><input type="submit" class="button" name="save" value="<?php echo $lang_admin['Save changes'] ?>" /></p>
			</div>
			</form>
		</div>
	</div>

</div>
<?php

}

require PUN_ROOT.'footer.php';
