<?php
/***********************************************************************

  Copyright (C) 2002-2007  Rickard Andersson (rickard@punbb.org)

  This file is part of PunBB.

  PunBB is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  PunBB is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************/


// Tell common.php that we don't want output buffering
define('PUN_DISABLE_BUFFERING', 1);

define('PUN_ROOT', '../');
require PUN_ROOT.'include/common.php';
require PUN_ROOT.'include/common_admin.php';


if ($pun_user['g_id'] != PUN_ADMIN)
	message($lang_common['No permission']);

// Commented out by Paul because I needed to test the output
//if ($db_type == 'mysql' || $db_type == 'mysqli')
//	message($lang_common['Bad request']);

// Load the admin.php language file
require PUN_ROOT.'lang/'.$pun_user['language'].'/admin.php';


if (isset($_GET['i_per_page']) && isset($_GET['i_start_at']))
{
	$per_page = intval($_GET['i_per_page']);
	$start_at = intval($_GET['i_start_at']);
	if ($per_page < 1 || $start_at < 1)
		message($lang_common['Bad request']);

	@set_time_limit(0);

	// If this is the first cycle of posts we empty the search index before we proceed
	if (isset($_GET['i_empty_index']))
	{
		$db->query('DELETE FROM '.$db->prefix.'search_matches') or error('Unable to empty search index match table', __FILE__, __LINE__, $db->error());
		$db->query('DELETE FROM '.$db->prefix.'search_words') or error('Unable to empty search index words table', __FILE__, __LINE__, $db->error());

		// Reset the sequence for the search words (not needed for SQLite)
		if ($db_type == 'pgsql')
			$result = $db->query('SELECT setval(\''.$db->prefix.'search_words_id_seq\', 1, false)') or error('Unable to update sequence', __FILE__, __LINE__, $db->error());
	}

	$end_at = $start_at + $per_page;

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html lang="<?php $lang_common['lang_identifier'] ?>" dir="<?php echo $lang_common['lang_direction'] ?>">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

<title><?php echo htmlspecialchars($pun_config['o_board_title']) ?> - Rebuilding search index …</title>
<style type="text/css">
body {
	font: 68.75% Verdana, Arial, Helvetica, sans-serif;
	color: #333333;
	background-color: #FFFFFF
}
</style>
</head>
<body>

<p><?php echo $lang_admin['Rebuilding index'] ?></p>

<?php

	require PUN_ROOT.'include/search_idx.php';

	// Fetch posts to process
	$result = $db->query('SELECT DISTINCT t.id, p.id, p.message FROM '.$db->prefix.'topics AS t INNER JOIN '.$db->prefix.'posts AS p ON t.id=p.topic_id WHERE t.id>='.$start_at.' AND t.id<'.$end_at.' ORDER BY t.id') or error('Unable to fetch topic/post info', __FILE__, __LINE__, $db->error());

	$cur_topic = 0;
	echo '<p>';
	while ($cur_post = $db->fetch_row($result))
	{
		if ($cur_post[0] <> $cur_topic)
		{
			// Fetch subject and ID of first post in topic
			$result2 = $db->query('SELECT p.id, t.subject, MIN(p.posted) AS first FROM '.$db->prefix.'posts AS p INNER JOIN '.$db->prefix.'topics AS t ON t.id=p.topic_id WHERE t.id='.$cur_post[0].' GROUP BY p.id, t.subject ORDER BY first LIMIT 1') or error('Unable to fetch topic info', __FILE__, __LINE__, $db->error());
			list($first_post, $subject) = $db->fetch_row($result2);

			$cur_topic = $cur_post[0];
		}

		printf($lang_admin['Processing post'], $cur_post[1], $cur_post[0]).'<br />'."\n";

		if ($cur_post[1] == $first_post)	// This is the "topic post" so we have to index the subject as well
			update_search_index('post', $cur_post[1], $cur_post[2], $subject);
		else
			update_search_index('post', $cur_post[1], $cur_post[2]);
	}
	echo '</p>';

	// Check if there is more work to do
	$result = $db->query('SELECT id FROM '.$db->prefix.'topics WHERE id>'.$end_at) or error('Unable to fetch topic info', __FILE__, __LINE__, $db->error());

	$query_str = ($db->num_rows($result)) ? '?i_per_page='.$per_page.'&i_start_at='.$end_at : '';

	$db->end_transaction();
	$db->close();

	exit('<script type="text/javascript">window.location="'.pun_link($pun_url['admin_reindex']).$query_str.'"</script><br />'.$lang_admin['Javascript redirect'].' <a href="'.pun_link($pun_url['admin_reindex']).$query_str.'">'.$lang_admin['Click to continue'].'</a>.');
}


// Get the first topic ID from the db
$result = $db->query('SELECT id FROM '.$db->prefix.'topics ORDER BY id LIMIT 1') or error('Unable to fetch topic info', __FILE__, __LINE__, $db->error());
if ($db->num_rows($result))
	$first_id = $db->result($result);


// Setup breadcrumbs
$pun_page['crumbs'] = array(
	array($pun_config['o_board_title'], pun_link($pun_url['index'])),
	array($lang_admin['Forum administration'], pun_link($pun_url['admin_index'])),
	$lang_admin['Rebuild index']
);

define('PUN_PAGE_SECTION', 'management');
define('PUN_PAGE', 'admin-reindex');
require PUN_ROOT.'header.php';

?>
<div id="pun-main1" class="a-section a-main a-admin">

	<h1 class="main-title"><span><?php echo end($pun_page['crumbs']) ?></span></h1>

<?php echo generate_admin_menu(); ?>

	<div class="b-section b-dataform">
		<div class="c-section c-form">
			<form method="get" accept-charset="utf-8" action="<?php echo pun_link($pun_url['admin_reindex']) ?>">
			<div class="panel">
				<input type="hidden" name="csrf_token" value="<?php echo $pun_user['csrf_token'] ?>" />
				<div class="form-intro">
					<h2 class="prefix"><span><?php echo $lang_admin['Reindex heading'] ?>: </span></h2>
					<p><?php echo $lang_admin['Reindex info'] ?></p>
				</div>
				<fieldset class="textset" id="fs1">
					<legend><span><?php echo $lang_admin['Rebuild index legend'] ?></span></legend>
					<p class="field">
						<label for="fs1f1"><?php echo $lang_admin['Topics per cycle'] ?></label><br />
						<span class="input"><input type="text" id="fs1f1" name="i_per_page" size="7" maxlength="7" value="100" /><br /> <em class="field-info"><?php echo $lang_admin['Topics per cycle info'] ?></em></span><br />
					</p>
					<p class="field">
						<label for="fs1f2"><?php echo $lang_admin['Starting topic'] ?></label><br />
						<span class="input"><input type="text" id="fs1f2" name="i_start_at" size="7" maxlength="7" value="<?php echo (isset($first_id)) ? $first_id : 0 ?>" /><br /> <em class="field-info"><?php echo $lang_admin['Starting topic info'] ?></em></span><br />
					</p>
				</fieldset>
				<fieldset class="checkset" id="fs2">
					<legend><span><?php echo $lang_admin['Empty index'] ?></span></legend>
					<p class="field">
						<span class="input"><input type="checkbox" id="fs2f1" name="i_empty_index" value="1" checked="checked" /> <label for="fs2f1"><?php echo $lang_admin['Empty index info'] ?></label></span><br />
					</p>
				</fieldset>
				<div class="form-warn">
					<p><?php echo '<strong>'.$lang_admin['Important'].'</strong> '.$lang_admin['Reindex warning'] ?></p>
				</div>
				<p class="formsubmit"><input type="submit" class="button" name="rebuild_index" value="<?php echo $lang_admin['Rebuild index'] ?>" /></p>
			</div>
			</form>
		</div>
	</div>

</div>
<?php

require PUN_ROOT.'footer.php';
